from sqlmodel import SQLModel

from .domain.base import CoreModel
from .requests.base import BaseRequestModel
from .responses.base_model import BaseResponseModel, BaseAIValidationModel
from flask_structured_api.core.enums import UserRole, WarningCode, WarningSeverity, StorageType
from .errors import (
    ErrorDetail, ValidationErrorItem, ValidationErrorDetail,
    HTTPErrorDetail, DatabaseErrorDetail, AuthErrorDetail
)

# Domain models
from .domain.user import User
from .domain.storage import StorageBase, APIStorage
from .domain.api_key import APIKey

# Request models
from .requests.auth import LoginRequest, RegisterRequest, RefreshTokenRequest, APIKeyRequest
from .requests.storage import StorageQueryRequest, SessionQueryRequest

# Response models
from .responses import (
    ErrorResponse, SuccessResponse,
    StorageEntryResponse, StorageListResponse,
    SimpleSessionListResponse, DetailedSessionListResponse,
    SessionListItemResponse, SessionWithEntriesResponse,
    TokenResponse, UserResponse,
    ItemResponse, ItemListResponse,
    AIResponse
)

__all__ = [
    # SQLAlchemy models
    'SQLModel',

    # Base models
    'CoreModel', 'BaseRequestModel', 'BaseResponseModel', 'BaseAIValidationModel',

    # Enums
    'UserRole', 'WarningCode', 'WarningSeverity', 'StorageType',

    # Error models
    'ErrorDetail', 'ValidationErrorItem', 'ValidationErrorDetail',
    'HTTPErrorDetail', 'DatabaseErrorDetail', 'AuthErrorDetail',

    # Domain models
    'User', 'StorageBase', 'APIStorage', 'APIKey',

    # Request models
    'LoginRequest', 'RegisterRequest', 'RefreshTokenRequest', 'APIKeyRequest',
    'StorageQueryRequest', 'SessionQueryRequest',

    # Response models
    'ErrorResponse', 'SuccessResponse',
    'StorageEntryResponse', 'StorageListResponse',
    'SimpleSessionListResponse', 'DetailedSessionListResponse',
    'SessionListItemResponse', 'SessionWithEntriesResponse',
    'TokenResponse', 'UserResponse',
    'ItemResponse', 'ItemListResponse',
    'AIResponse'
]
